@@ -5,7 +5,6 @@ package Win32::Event;
 #
 # Author: Christopher J. Madsen <perl@cjmweb.net>
 # Created: 3 Feb 1998 from the ActiveWare version
-# $Id: Event.pm 284 2008-04-17 02:17:41Z cmadsn $
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
@@ -15,7 +14,7 @@ package Win32::Event;
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See either the
 # GNU General Public License or the Artistic License for more details.
 #
-# Use Win32 event objects for synchronization
+# ABSTRACT: Use Win32 event objects from Perl
 #---------------------------------------------------------------------
 
 use strict;
@@ -26,7 +25,8 @@ use Win32::IPC 1.00 '/./';      # Import everything
 
 BEGIN
 {
-  $VERSION = '1.07';
+  $VERSION = '1.08';
+  # This file is part of {{$dist}} {{$dist_version}} ({{$date}})
 
   @ISA = qw(Win32::IPC);        # Win32::IPC isa Exporter
   @EXPORT_OK = qw(
@@ -38,7 +38,6 @@ BEGIN
 } # end BEGIN bootstrap
 
 1;
-__END__
 
 =head1 NAME
 
@@ -46,8 +45,9 @@ Win32::Event - Use Win32 event objects from Perl
 
 =head1 VERSION
 
-This document describes version 1.07 of Win32::Event, released April 16, 2008 as part of Win32-IPC version 1.07.
-
+This document describes version 1.08 of
+Win32::Event, released December 11, 2010
+as part of Win32-IPC version 1.08.
 
 =head1 SYNOPSIS
 
@@ -119,7 +119,6 @@ Wait for C<$event> to be signalled.  See L<Win32::IPC>.
 
 None.
 
-
 =head1 CONFIGURATION AND ENVIRONMENT
 
 Win32::Event requires no configuration files or environment variables.
@@ -127,43 +126,40 @@ Win32::Event requires no configuration files or environment variables.
 It runs under 32-bit or 64-bit Microsoft Windows, either natively or
 under Cygwin.
 
-
 =head1 DEPENDENCIES
 
 L<Win32::IPC>
 
-
 =head1 INCOMPATIBILITIES
 
-Prior to version 1.06, Win32::Event treated C<undef> values
+Prior to version 1.06, the Win32 IPC modules treated C<undef> values
 differently.  In version 1.06 and later, passing C<undef> as the value
 of an optional parameter is the same as omitting that parameter.  In
 previous versions, C<undef> was interpreted as either the empty string
 or 0 (along with a warning about "Use of uninitialized value...").
 
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
-
 =head1 AUTHOR
 
-Christopher J. Madsen E<lt>F<perl AT cjmweb.net>E<gt>
+Christopher J. Madsen  S<C<< <perl AT cjmweb.net> >>>
 
 Please report any bugs or feature requests to
-S<< C<< <bug-Win32-IPC AT rt.cpan.org> >> >>,
+S<C<< <bug-Win32-IPC AT rt.cpan.org> >>>,
 or through the web interface at
 L<http://rt.cpan.org/Public/Bug/Report.html?Queue=Win32-IPC>
 
+You can follow or contribute to Win32-IPC's development at
+L<< http://github.com/madsen/win32-ipc >>.
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 1998-2008 Christopher J. Madsen
-
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+This software is copyright (c) 2010 by Christopher J. Madsen.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =head1 DISCLAIMER OF WARRANTY
 
@@ -190,6 +186,9 @@ SUCH DAMAGES.
 
 =cut
 
+__END__
+
+
 # Local Variables:
 # tmtrack-file-task: "Win32::Event"
 # End:
