@@ -10,7 +10,6 @@ package Win32::IPC;
 #   Other modifications (c) 1997 by Gurusamy Sarathy <gsar@cpan.org>
 #
 # Author: Christopher J. Madsen <perl@cjmweb.net>
-# $Id: IPC.pm 284 2008-04-17 02:17:41Z cmadsn $
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
@@ -20,7 +19,7 @@ package Win32::IPC;
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See either the
 # GNU General Public License or the Artistic License for more details.
 #
-# Base class for Win32 synchronization objects
+# ABSTRACT: Base class for Win32 synchronization objects
 #---------------------------------------------------------------------
 
 use strict;
@@ -29,7 +28,8 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 
 BEGIN
 {
-  $VERSION = '1.07';
+  $VERSION = '1.08';
+  # This file is part of {{$dist}} {{$dist_version}} ({{$date}})
 
   require Exporter;
   @ISA       = qw( Exporter );
@@ -41,7 +41,7 @@ BEGIN
 
   # Generate INFINITE constant function:
   my $INFINITE = constant('INFINITE');
-  eval "sub INFINITE () { $INFINITE } 1" or die;
+  do { local $@; eval "sub INFINITE () { $INFINITE } 1" } or die;
 } # end BEGIN bootstrap
 
 # How's this for cryptic?  Use wait_any or wait_all!
@@ -56,7 +56,6 @@ sub WaitForMultipleObjects
 } # end WaitForMultipleObjects
 
 1;
-__END__
 
 =head1 NAME
 
@@ -64,8 +63,9 @@ Win32::IPC - Base class for Win32 synchronization objects
 
 =head1 VERSION
 
-This document describes version 1.07 of Win32::IPC, released April 16, 2008 as part of Win32-IPC version 1.07.
-
+This document describes version 1.08 of
+Win32::IPC, released December 11, 2010
+as part of Win32-IPC version 1.08.
 
 =head1 SYNOPSIS
 
@@ -90,7 +90,7 @@ synchronization modules (or just Win32::IPC)).
 
 =head2 Methods
 
-B<Win32::IPC> supplies one method to all synchronization objects.
+Win32::IPC supplies one method to all synchronization objects.
 
 =over 4
 
@@ -141,7 +141,7 @@ is an abandoned mutex.
 
 =head2 Deprecated Functions and Methods
 
-B<Win32::IPC> still supports the ActiveWare syntax, but its use is
+Win32::IPC still supports the ActiveWare syntax, but its use is
 deprecated.
 
 =over 4
@@ -179,12 +179,10 @@ When called in scalar context with no arguments, this method should
 return a Win32 HANDLE (as an IV) suitable for passing to the Win32
 WaitForMultipleObjects API function.
 
-
 =head1 DIAGNOSTICS
 
 None.
 
-
 =head1 CONFIGURATION AND ENVIRONMENT
 
 Win32::IPC requires no configuration files or environment variables.
@@ -192,11 +190,12 @@ Win32::IPC requires no configuration files or environment variables.
 It runs under 32-bit or 64-bit Microsoft Windows, either natively or
 under Cygwin.
 
-
 =head1 DEPENDENCIES
 
 None.
 
+=for Pod::Coverage
+^constant$
 
 =head1 INCOMPATIBILITIES
 
@@ -206,38 +205,37 @@ of an optional parameter is the same as omitting that parameter.  In
 previous versions, C<undef> was interpreted as either the empty string
 or 0 (along with a warning about "Use of uninitialized value...").
 
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
-
 =head1 AUTHOR
 
-Christopher J. Madsen E<lt>F<perl AT cjmweb.net>E<gt>
+Christopher J. Madsen  S<C<< <perl AT cjmweb.net> >>>
 
 Please report any bugs or feature requests to
-S<< C<< <bug-Win32-IPC AT rt.cpan.org> >> >>,
+S<C<< <bug-Win32-IPC AT rt.cpan.org> >>>,
 or through the web interface at
 L<http://rt.cpan.org/Public/Bug/Report.html?Queue=Win32-IPC>
 
+You can follow or contribute to Win32-IPC's development at
+L<< http://github.com/madsen/win32-ipc >>.
+
 Loosely based on the original module by ActiveWare Internet Corp.,
 L<http://www.ActiveState.com>
 
+=head1 COPYRIGHT AND LICENSE
 
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 1998-2008 Christopher J. Madsen
+Copyright 1998-2010 Christopher J. Madsen
 
 Created: 3 Feb 1998 from the ActiveWare version
   (c) 1995 Microsoft Corporation. All rights reserved.
       Developed by ActiveWare Internet Corp., http://www.ActiveState.com
 
-  Other modifications (c) 1997 by Gurusamy Sarathy <gsar@cpan.org>
-
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+  Other modifications (c) 1997 by Gurusamy Sarathy <gsar AT cpan.org>
 
+This module is free software; you can redistribute it and/or modify it
+under the same terms as the Perl 5 programming language system itself.
 
 =head1 DISCLAIMER OF WARRANTY
 
@@ -264,6 +262,9 @@ SUCH DAMAGES.
 
 =cut
 
+__END__
+
+
 # Local Variables:
 # tmtrack-file-task: "Win32::IPC"
 # End:
